#pragma once

#include "includes.h"

class Obrazek
{
private:
	std::unique_ptr<Magick::Image> _image;
	Glib::RefPtr<Gdk::Pixbuf> _pixbuf;
	
public:
	~Obrazek() noexcept
	{
		_pixbuf.reset();
		_image.reset();
	}

public:
	void nacist(const char* soubor)
	{
		_image.reset();
		_image = std::make_unique<Magick::Image>(soubor);
		aktualizovat_data();
	}

	bool je_nacten() noexcept
	{
		return (_image && _image->isValid());
	}

	void aktualizovat_data() noexcept
	{
		if (!je_nacten())
			return;
		_pixbuf.reset();
		Magick::Blob blob;
		_image->write(&blob);
		Glib::RefPtr< Gio::MemoryInputStream > ms = Gio::MemoryInputStream::create();
		ms->add_data((const void*)blob.data(), blob.length());
		_pixbuf = Gdk::Pixbuf::create_from_stream(ms);
		ms.reset();
	}
	
	Gdk::Pixbuf* get_pixbuf() noexcept
	{
		assert(_image.get());
		return _pixbuf.get();
	}
	
	Magick::Image* get_image() noexcept
	{
		assert(_image.get());
		return _image.get();
	}
};